<?php

/**
 * Declare common (backend|frontend) global functions here
 * but try not to use any global functions unless you need.
 */

if (! function_exists('dd')) {
    function dd()
    {
        foreach (func_get_args() as $value) {
            echo "<pre>";
            print_r($value);
            echo "</pre><br>";
        }
        die;
    }
}

if (! function_exists('fluentformMix')) {
    /**
     * Get the path to a versioned Mix file.
     *
     * @param string $path
     * @param string $manifestDirectory
     *
     * @return string
     * @throws \Exception
     */
    function fluentformMix($path, $manifestDirectory = '')
    {
        $env = \FluentForm\App::make('config')->app['env'];

        if ($env != 'dev') {
            $publicUrl = \FluentForm\App::publicUrl();

            return $publicUrl.$path;
        }

        static $manifests = [];

        if (substr($path, 0, 1) !== '/') {
            $path = "/".$path;
        }

        if ($manifestDirectory && substr($manifestDirectory, 0, 1) !== '/') {
            $manifestDirectory = "/".$manifestDirectory;
        }

        $publicPath = \FluentForm\App::publicPath();
        if (file_exists($publicPath.'/hot')) {
            return (is_ssl() ? "https" : "http")."://localhost:8080".$path;
        }

        $manifestPath = $publicPath.$manifestDirectory.'mix-manifest.json';

        if (! isset($manifests[$manifestPath])) {
            if (! file_exists($manifestPath)) {
                throw new Exception('The Mix manifest does not exist.');
            }

            $manifests[$manifestPath] = json_decode(file_get_contents($manifestPath), true);
        }

        $manifest = $manifests[$manifestPath];

        if (! isset($manifest[$path])) {
            throw new Exception(
                "Unable to locate Mix file: ".$path.". Please check your ".
                'webpack.mix.js output paths and try again.'
            );
        }

        return \FluentForm\App::publicUrl($manifestDirectory.$manifest[$path]);
    }
}

if (! function_exists('fluentFormSanitizer')) {
    /**
     * Sanitize form inputs recursively.
     *
     * @param $input
     *
     * @return string $input
     */
    function fluentFormSanitizer($input, $attribute = null, $fields = [])
    {
        if (is_string($input)) {
            if (\FluentForm\Framework\Helpers\ArrayHelper::get($fields, $attribute.'.element') === 'textarea') {
                $input = sanitize_textarea_field($input);
            } else {
                $input = sanitize_text_field($input);
            }
        } elseif (is_array($input)) {
            foreach ($input as $key => &$value) {
                $attribute = $attribute ? $attribute.'['.$key.']' : $key;

                $value = fluentFormSanitizer($value, $attribute, $fields);

                $attribute = null;
            }
        }

        return $input;
    }
}

if (! function_exists('fluentFormEditorShortCodes')) {
    function fluentFormEditorShortCodes()
    {
        $editor_shortcodes = array(
            array(
                'title'      => 'General Shortcodes',
                'shortcodes' => array(
                    '{ip}'                    => __('IP Address', 'fluentform'),
                    '{date.m/d/Y}'            => __('Date (mm/dd/yyyy)', 'fluentform'),
                    '{date.d/m/Y}'            => __('Date (dd/mm/yyyy)', 'fluentform'),
                    '{embed_post.ID}'         => __('Embebeded Post/Page ID', 'fluentform'),
                    '{embed_post.post_title}' => __('Embebeded Post/Page Title', 'fluentform'),
                    '{embed_post.permalink}'  => __('Embebeded URL', 'fluentform'),
                    '{user.ID}'               => __('User ID', 'fluentform'),
                    '{user.display_name}'     => __('User Display Name', 'fluentform'),
                    '{user.first_name}'       => __('User First Name', 'fluentform'),
                    '{user.last_name}'        => __('User Last Name', 'fluentform'),
                    '{user.user_email}'       => __('User Email', 'fluentform'),
                    '{user.user_login}'       => __('User Username', 'fluentform'),
                    '{browser.name}'          => __('User Browser Client', 'fluentform'),
                    '{browser.platform}'      => __('User Operating System', 'fluentform')
                )
            )
        );
        return apply_filters('fluentform_editor_shortcodes', $editor_shortcodes);
    }
}

if (!function_exists('implodeRecursive')) {
    /**
     * Recursively implode a multi-dimentional array
     * @param string $glue
     * @param array $array
     * @return string
     */
    function implodeRecursive($glue, array $array) {
        $fn = function($glue, array $array) use (&$fn) {
            $result = '';
            foreach ($array as $item) {
                if(is_array($item)) {
                    $result .= $fn($glue, $item);
                } else {
                    $result .= $glue . $item;
                }
            }
            return $result;
        };

        return ltrim($fn($glue, $array), $glue);
    }
}
