<?php

/**
 * Declare backend actions/filters/shortcodes
 */

/**
 * @var $app \FluentForm\Framework\Foundation\Application
 */

// Add Entries Menu
$app->addAction('ff_fluentform_form_application_view_entries', function ($form_id) use ($app) {
    (new \FluentForm\App\Modules\Entries\Entries())->renderEntries($form_id);
});

$app->addAction('fluentform_after_form_navigation_editor', function ($form_id) use ($app) {
    (new \FluentForm\App\Modules\Registerer\Menu($app))->addPreviewButton($form_id);
});

$app->addAction('media_buttons', function () {
    (new \FluentForm\App\Modules\EditorButtonModule())->addButton();
});

// On form submission register slack notifier
use FluentForm\App\Services\Slack;

$app->addAction(
    'fluentform_submission_inserted',
    function ($submissionId, $formData, $form) {
        Slack::notify($submissionId, $formData, $form);
    },
    10, 3
);

// On form submission register MailChimp subscriber.
use FluentForm\App\Modules\Integration\MailChimpIntegration as MailChimp;

$app->addAction(
    'fluentform_submission_inserted',
    function ($submissionId, $formData, $form) use ($app) {
        (new MailChimp($app))->subscribe($formData);
    },
    10, 3
);

$app->addAction('admin_init', function () {
    (new FluentForm\App\Modules\Track\TrackModule())->initTrack();
});

$app->addAction('admin_notices', function () {
    FluentForm\AdminNotice::showNotice();
});


$app->addAction('fluentform_addons_page_render_fluentform_add_ons', function () {
	(new \FluentForm\App\Modules\AddOnModule() )->showFluentAddOns();
});

/**
 * Register events to format the field values.
 * Response of the following elements' are
 * typically in array format and we just
 * need to concatenate it to a string.
 */
$elements = [
    'input_name',
    'select',
    'input_checkbox',
    'input_image',
    'input_file',
    'input_repeat',
    'address'
];

foreach ($elements as $element) {
    $event = 'fluentform_response_render_'.$element;

    $app->addfilter($event, function ($response) {
        return \FluentForm\App\Modules\Form\FormDataParser::formatValue($response);
    }, 10, 1);
}
