<?php

namespace FluentForm\App\Modules\Entries;

use SplTempFileObject;
use FluentForm\App\Modules\Form\FormDataParser;
use FluentForm\Framework\Foundation\Application;
use FluentForm\App\Modules\Form\FormFieldsParser;
use FluentForm\Framework\Helpers\ArrayHelper as Arr;

class Export
{
    /**
     * @var \FluentForm\Framework\Request\Request
     */
    protected $request;

    /**
     * Export constructor.
     *
     * @param \FluentForm\Framework\Foundation\Application $application
     */
    public function __construct(Application $application)
    {
        $this->request = $application->request;
    }

    /**
     * Exports form entries as CSV.
     *
     * @todo:: refactor.
     */
    public function index()
    {
        $formId = intval($this->request->get('form_id'));

        $form = wpFluent()->table('fluentform_forms')->find($formId);

        $formInputs = FormFieldsParser::getEntryInputs($form);

        $inputLabels = FormFieldsParser::getAdminLabels($form, $formInputs);

        $submissions = wpFluent()->table('fluentform_submissions')->where('form_id', $formId)->get();

        $submissions = FormDataParser::parseFormEntries($submissions, $form, $formInputs);

        $exportData = [];

        foreach ($submissions as $submission) {
            $responses = json_decode($submission->response, true);

            $temp = [];

            foreach ($inputLabels as $field => $label) {
                $temp[] = FormDataParser::formatValue(Arr::get($responses, $field));
            }

            $exportData[] = $temp;
        }

        $fileName = 'export-data-'.date('d-m-Y');

        $writer = \League\Csv\Writer::createFromFileObject(new SplTempFileObject());
        $writer->setDelimiter(',');
        $writer->setNewline("\r\n");
        $writer->insertOne($inputLabels);
        $writer->insertAll($exportData);
        $writer->output($fileName.'.csv');
        die();
    }
}
