<?php

/**
 * element_customization_settings
 *
 * Returns an array of countries and codes.
 *
 * @author      WooThemes
 * @category    i18n
 * @package     fluentform/i18n
 * @version     2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$element_customization_settings = array(
	'name'               => array(
		'template'  => 'inputText',
		'label'     => 'Name Attribute',
		'help_text' => 'This is the field name attributes which is used to submit form data, name attribute must be unique.',
	),
	'label'              => array(
		'template'  => 'inputText',
		'label'     => 'Element Label',
		'help_text' => 'This is the field title the user will see when filling out the form.',
	),
	'label_placement'    => array(
		'template'  => 'radioButton',
		'label'     => 'Label Placement',
		'help_text' => 'Determine the position of label title where the user will see this. By choosing "Default", global label placement setting will be applied.',
		'options'   => array(
			array(
				'value' => '',
				'label' => 'Default',
			),
			array(
				'value' => 'top',
				'label' => 'Top',
			),
			array(
				'value' => 'left',
				'label' => 'Left',
			),
			array(
				'value' => 'right',
				'label' => 'Right',
			),
		),
	),
	'placeholder'        => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Placeholder',
		'help_text' => 'This is the field placeholder, the user will see this if the input field is empty.',
	),
	'date_format'        => array(
		'template'  => 'select',
		'label'     => 'Date Format',
		'help_text' => 'Select any date format from the dropdown. The user will be able to choose a date in this given format.',
		'options'   => array(
			array(
				'value' => 'd/m/Y',
				'label' => 'DD/MM/YYYY',
			),
			array(
				'value' => 'd-m-Y',
				'label' => 'DD-MM-YYYY',
			),
			array(
				'value' => 'm/d/Y',
				'label' => 'MM/DD/YYYY',
			),
			array(
				'value' => 'm-d-Y',
				'label' => 'MM-DD-YYYY',
			),
			array(
				'value' => 'F d, Y',
				'label' => 'December 20, 2017',
			),
			array(
				'value' => 'd/m/Y h:i:s A',
				'label' => 'DD/MM/YYYY HH:MM:SS AM',
			),
			array(
				'value' => 'd-m-Y h:i:s A',
				'label' => 'DD-MM-YYYY HH:MM:SS AM',
			),
			array(
				'value' => 'm/d/Y h:i:s A',
				'label' => 'MM/DD/YYYY HH:MM:SS AM',
			),
			array(
				'value' => 'm-d-Y h:i:s A',
				'label' => 'MM-DD-YYYY HH:MM:SS AM',
			),
			array(
				'value' => 'F d, Y h:i:s A',
				'label' => 'December 20, 2017 09:59:23 AM',
			),
		),
	),
	'rows'               => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Rows',
		'help_text' => 'How many rows will textarea take in a form. It\'s an HTML attributes for browser support.',
	),
	'cols'               => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Cols',
		'help_text' => 'How many cols will textarea take in a form. It\'s an HTML attributes for browser support.',
	),
	'options'            => array(
		'element'   => 'select',
		'type'      => 'options',
		'label'     => 'Options',
		'help_text' => 'Create options for the field and checkmark them for default selection.',
	),
	'validation_rules'   => array(
		'template'  => 'validationRulesForm',
		'label'     => 'Validation Rules',
		'help_text' => '',
	),
	'tnc_html'           => array(
		'element'   => 'input',
		'type'      => 'textarea',
		'label'     => 'Terms & Conditions',
		'help_text' => 'Write HTML content for terms & condition checkbox',
		'rows'      => 5,
		'cols'      => 3,
	),
	'hook_name'          => array(
		'element'   => 'custom',
		'type'      => 'hookName',
		'label'     => 'Hook Name',
		'help_text' => 'WordPress Hook name to hook something in this place.',
	),
	'has_checkbox'       => array(
		'element' => 'input',
		'type'    => 'checkbox',
		'options' => array(
			array(
				'value' => true,
				'label' => 'Show Checkbox',
			),
		),
	),
	'html_codes'         => array(
		'element'   => 'input',
		'type'      => 'textarea',
		'rows'      => 4,
		'cols'      => 2,
		'label'     => 'HTML Code',
		'help_text' => 'Your valid HTML code will be shown to the user as normal content.',
	),
	'description'        => array(
		'element'   => 'input',
		'type'      => 'textarea',
		'rows'      => 4,
		'cols'      => 2,
		'label'     => 'Description',
		'help_text' => 'Description will be shown to the user as normal text content.',
	),
	'btn_text'           => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Button Text',
		'help_text' => 'This will be visible as button text for upload file.',
	),
	'button_ui'          => array(
		'template'  => 'prevNextButton',
		'label'     => 'Submit Button',
		'help_text' => 'This is form submission button.',
	),
	'align'              => array(
		'template'  => 'radio',
		'label'     => 'Content Alignment',
		'help_text' => 'How the content will be aligned.',
		'options'   => array(
			array(
				'value' => 'left',
				'label' => 'Left',
			),
			array(
				'value' => 'center',
				'label' => 'Center',
			),
			array(
				'value' => 'right',
				'label' => 'Right',
			),
		),
	),
	'shortcode'          => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Shortcode',
		'help_text' => 'Your shortcode to render desired content in current place.',
	),
	'step_title'         => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Step Title',
		'help_text' => 'Form step titles, user will see each title in each step.',
	),
	'progress_indicator' => array(
		'template'  => 'radio',
		'label'     => 'Progress Indicator',
		'help_text' => 'Select any of them below, user will see progress of form steps according to your choice.',
		'options'   => array(
			array(
				'value' => 'progress-bar',
				'label' => 'Progress Bar',
			),
			array(
				'value' => 'steps',
				'label' => 'Steps',
			),
			array(
				'value' => '',
				'label' => 'None',
			),
		),
	),
	'step_titles'        => array(
		'template'  => 'customStepTitles',
		'label'     => 'Step Titles',
		'help_text' => 'Form step titles, user will see each title in each step.',
	),
	'prev_btn'           => array(
		'template'  => 'prevNextButton',
		'label'     => 'Previous Button',
		'help_text' => 'Multi-step form\'s previous button',
	),
	'next_btn'           => array(
		'template'  => 'prevNextButton',
		'label'     => 'Next Button',
		'help_text' => 'Multi-step form\'s next button',
	),
	'address_fields'     => array(
		'template' => 'addressFields',
		'label'    => 'Address Fields',
	),
	'name_fields'        => array(
		'template' => 'nameFields',
		'label'    => 'Name Fields',
	),
	'multi_column'       => array(
		'element' => 'input',
		'type'    => 'checkbox',
		'options' => array(
			array(
				'value' => true,
				'label' => 'Enable Multiple Columns',
			),
		),
	),
	'repeat_fields'      => array(
		'element'   => 'custom',
		'type'      => 'repeatFields',
		'label'     => 'Repeat Fields',
		'help_text' => 'This is a form field which a user will be able to repeat.',
	),
	'admin_field_label'  => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Admin Field Label',
		'help_text' => 'Admin field label is field title which will be used for admin field title.',
	),
	'value'              => array(
		'label'     => 'Default Value',
		'template'  => 'inputValue',
		'help_text' => 'If you would like to pre-populate the value of a field, enter it here.',
	),
	'container_class'    => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Container Class',
		'help_text' => 'Class for the field wrapper. This can be used to style current element.',
	),
	'class'              => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Element Class',
		'help_text' => 'Class for the field. This can be used to style current element.',
	),
	'country_list'       => array(
		'element' => 'custom',
		'type'    => 'countryList',
		'label'   => 'Country List',
	),
	'help_message'       => array(
		'element'   => 'input',
		'type'      => 'text',
		'label'     => 'Help Message',
		'help_text' => 'Help message will be shown as tooltip next to sidebar or below the field.',
	),
	'conditional_logics' => array(
		'element'   => 'conditionalLogics',
		'label'     => 'Conditional Logic',
		'help_text' => 'Create rules to dynamically display or hide this field based on values from another field.',
	),
);

return apply_filters( 'fluent_editor_element_customization_settings', $element_customization_settings );