<?php

namespace FluentForm\App\Services\FormBuilder;

use FluentForm\App;
use FluentForm\App\Modules\Form\FormDataParser;
use FluentForm\App\Modules\Form\FormFieldsParser;
use FluentForm\Framework\Helpers\ArrayHelper;

class MessageShortCodeParser
{
	protected static $data = null;

	/**
	 * Parse Norifications
	 * @param array $notifications
     * @param int $insertId
     * @param array $data
     * @param object $form
	 * @return  array $notifications
	 */
	public static function parseMessageShortCode($notifications, $insertId, $data, $form, $cache = true)
    {
    	if ($cache && !is_null(static::$data)) {
    		return static::$data;
    	}

    	$formattedProperties = array();

        $parsableFields = array(
            'fromName',
            'fromEmail',
            'replyTo',
            'bcc',
            'subject',
            'message'
        );

        list(
        	$formProperties,
        	$userProperties,
        	$postProperties,
        	$others
        ) = static::parsePropertiesFor($parsableFields, $notifications);

        static::setOtherProperties($formattedProperties, $others, $data, $form, $insertId);
        static::setUserProperties($formattedProperties, $userProperties, $data, $form, $insertId);
        static::setPostProperties($formattedProperties, $postProperties, $data, $form, $insertId);
        static::setFormProperties($formattedProperties, $formProperties, $data, $form, $insertId);

		// If any property is array then make it string
		foreach ($formattedProperties as $key => $formattedProperty) {
			if(is_array($formattedProperty)) {
				$formattedProperties[$key] = implode(', ',$formattedProperty);
			}
		}

		foreach ($notifications as &$notification) {
			if ($notification['sendTo']['type'] == 'field') {
				$notification['sendTo']['email'] = $formattedProperties['inputs.email'];
			}

			foreach ($parsableFields as $fieldName) {
				if (isset($notification[$fieldName])) {
					foreach ($formattedProperties as $key => $value) {
						$notification[$fieldName] = str_replace(
							'{'.$key.'}', $value, $notification[$fieldName]
						);
					}
				}
            }
		}

		return $cache ? (static::$data = $notifications) : $notifications;
    }

    public static function parsePropertiesFor($parsableFields, $notifications)
    {
    	$totalString = '';
        foreach ($notifications as $notification) {
	        if ($notification['sendTo']['type'] == 'field') {
	        	$totalString .= '{inputs.'.$notification['sendTo']['field'].'}';
	        }
	        foreach ($parsableFields as $fieldName) {
		        $totalString .= $notification[$fieldName];
            }
        }

        preg_match_all('/{(.*?)}/', $totalString, $matches);
        $uniqueMatches = array_unique($matches[1]);
        $replacables =  array_unique($matches[0]);
		$formProperties = $userProperties = $postProperties = $others = array();
		foreach ($uniqueMatches as $match) {
			if (strpos($match, 'user.') !== false) {
				$userProperties[] = substr($match, strlen('user.'));
			} elseif (strpos($match, 'inputs.') !== false) {
				$formProperties[] = substr($match, strlen('inputs.'));
			} elseif (strpos($match, 'embed_post.') !== false) {
				$postProperties[] = substr($match, strlen('embed_post.'));
			} else {
				$others[] = $match;
			}
		}

		return array($formProperties, $userProperties, $postProperties, $others);
    }

    public static function setFormProperties(&$formattedProperties, $formProperties, $data, $form, $insertId)
    {
    	if (!$formProperties) return;
    	
	    $formFields = FormFieldsParser::getShortCodeInputs($form, ['admin_label', 'attributes', 'options']);
		
		foreach ($formProperties as $formProperty) {
			$field = @$formFields[$formProperty];
			
			$formattedProperties['inputs.'.$formProperty] = App::applyFilters(
				'fluentform_response_render_'.$field['element'],
				ArrayHelper::get($data, $formProperty, ''),
				$field,
				$form->id
			);
		}
    }

    public static function setUserProperties(&$formattedProperties, $userProperties, $data, $form, $insertId)
    {
    	if (!$userProperties) return;

    	$user = wp_get_current_user();
		foreach ($userProperties as $userProperty) {
			$formattedProperties['user.'.$userProperty] = $user->{$userProperty};
		}
    }

    public static function setPostProperties(&$formattedProperties, $postProperties, $data, $form, $insetId)
    {
    	if (!$postProperties) return;

    	$embed_post_id = @$data['__fluent_form_embded_post_id'];
		if($embed_post_id) {
			$post = get_post($embed_post_id);
			$post->permalink = get_the_permalink($post);
			foreach ($postProperties as $post_property) {
				$formattedProperties['embed_post.'.$post_property] = $post->{$post_property};
			}
		}
    }

    public static function setOtherProperties(&$formattedProperties, $others, $data, $form, $insertId)
    {
    	if (!$others) return;

    	foreach ($others as $other) {
			if ($other == 'date.m/d/Y') {
				$formattedProperties[$other] = date('m/d/Y');
				continue;
			} elseif ($other == 'date.d/m/Y') {
				$formattedProperties[$other] = date('d/m/Y');
				continue;
			} elseif ($other == 'browser.platform') {
				$browser = new \FluentForm\App\Services\Browser\Browser();
				$formattedProperties[$other] = $browser->getPlatform();
				continue;
			} elseif ($other == 'browser.name') {
				$browser = new \FluentForm\App\Services\Browser\Browser();
				$formattedProperties[$other] = $browser->getBrowser();
				continue;
			} elseif ($other == 'ip') {
				$formattedProperties[$other] = App::make('request')->getIp();
				continue;
			} elseif ($other == 'admin_email') {
                $formattedProperties[$other] = get_option('admin_email', false);
                continue;
            } else if($other == 'all_data') {
				$formFields = FormFieldsParser::getEntryInputs($form);
				$inputLabels = FormFieldsParser::getAdminLabels($form, $formFields);
				$entry = wpFluent()->table('fluentform_submissions')->find($insertId);
				$response = FormDataParser::parseFormSubmission($entry, $form, $formFields);
				$html = '';
				foreach ($inputLabels as $key => $label) {
					if (array_key_exists($key, $response->user_inputs)) {
						$html .= $label .': '. $response->user_inputs[$key] . '<br>';
					}
				}
				$formattedProperties[$other] = $html;
            }
		}
    }
}
