<?php

namespace FluentForm\App\Services\FormBuilder\Notifications;

use FluentForm\Framework\Foundation\Application;
use FluentForm\App\Modules\Form\FormFieldsParser;

class EmailNotification
{
    /**
     * FluentForm\Framework\Foundation\Application
     * @var $app
     */
    protected $app = null;

    /**
     * Biuld the instance of this class
     * @param  FluentForm\Framework\Foundation\Application $app
     * @return $this
     */
    public function __construct(Application $app)
    {
        $this->app = $app;
    }

    /**
     * Send the email notification
     * @param  array    $notification  [Notification settings from form meta]
     * @param  array    $submittedData [User submitted form data]
     * @param  StdClass $form          [The form object from database]
     * @return bool
     */
    public function notify($notification, $submittedData, $form)
    {
        $headers = [
            'Content-Type: text/html; charset=UTF-8'
        ];

        if ($notification['fromName'] && $notification['fromEmail']) {
            $headers[] = "From: {$notification['fromName']} <{$notification['fromEmail']}>";
        } elseif ($notification['fromName']) {
            $headers[] = "From: {$notification['fromName']}";
        } elseif ($notification['fromEmail']) {
            $headers[] = "From: <{$notification['fromEmail']}>";
        }

        if ($notification['replyTo']) {
            $headers[] = "Reply-To: <{$notification['replyTo']}>";
        }

        $headers = apply_filters('fluenttform_email_header', $headers, $notification);

        return wp_mail(
            $notification['sendTo']['email'],
            $notification['subject'],
            $notification['message'],
            $headers
        );
    }

    /**
     * @param $formId
     * @todo: Implement Caching mechanism so we don't have to parse these things for every request
     * @return array
     */
    private function getFormInputsAndLabels($form)
    {
        $formInputs = FormFieldsParser::getInputs($form);

        $inputLabels = FormFieldsParser::getAdminLabels($form, $formInputs);

        return [
            'inputs' => $formInputs,
            'labels' => $inputLabels
        ];
    }
}
