<?php

/**
 * validation_rule_settings
 *
 * Returns an array of countries and codes.
 *
 * @author      WooThemes
 * @category    i18n
 * @package     fluentform/i18n
 * @version     2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$validation_rule_settings = array(
	'required'            =>
		array(
			'template'  => 'inputRadio',
			'label'     => 'Required',
			'help_text' => 'Select whether this field is a required field for the form or not.',
			'options'   =>
				array(
					array(
						'value' => true,
						'label' => 'Yes',
					),
					array(
						'value' => false,
						'label' => 'No',
					),
				),
		),
	'min'                 =>
		array(
			'template'  => 'inputText',
			'type'      => 'number',
			'label'     => 'Min Value',
			'help_text' => 'Minimum value for the input field.',
		),
	'max'                 =>
		array(
			'template'  => 'inputText',
			'type'      => 'number',
			'label'     => 'Max Value',
			'help_text' => 'Maximum value for the input field.',
		),
	'max_file_size'       =>
		array(
			'template'  => 'maxFileSize',
			'label'     => 'Max File Size',
			'help_text' => 'The file size limit uploaded by the user.',
		),
	'max_file_count'      =>
		array(
			'template'  => 'inputText',
			'type'      => 'number',
			'label'     => 'Max Files Count',
			'help_text' => 'Maximum user file upload number.',
		),
	'allowed_file_types'  =>
		array(
			'template'  => 'inputCheckbox',
			'label'     => 'Allowed Files',
			'help_text' => 'Allowed Files',
			'fileTypes' =>
				array(
					array(
						'title' => 'Images',
						'types' => array( 'jpg', 'jpeg', 'gif', 'png', 'bmp' ),
					),
					array(
						'title' => 'Audio',
						'types' => array( 'mp3', 'wav', 'ogg', 'wma', 'mka', 'm4a', 'ra', 'mid', 'midi', ),
					),
					array(
						'title' => 'Video',
						'types' => array(
							'avi',
							'divx',
							'flv',
							'mov',
							'ogv',
							'mkv',
							'mp4',
							'm4v',
							'divx',
							'mpg',
							'mpeg',
							'mpe',
						),
					),
					array(
						'title' => 'PDF',
						'types' => array( 'pdf' ),
					),
					array(
						'title' => 'Docs',
						'types' => array(
							'doc',
							'ppt',
							'pps',
							'xls',
							'mdb',
							'docx',
							'xlsx',
							'pptx',
							'odt',
							'odp',
							'ods',
							'odg',
							'odc',
							'odb',
							'odf',
							'rtf',
							'txt'
						),
					),
					array(
						'title' => 'Zip Archives',
						'types' => array( 'zip', 'gz', 'gzip', 'rar', '7z', ),
					),
					array(
						'title' => 'Executable Files',
						'types' =>
							array( 'exe' ),
					),
					array(
						'title' => 'CSV',
						'types' => array( 'csv' ),
					),
				),
			'options'   => array(
				array(
					'label' => 'Images (jpg, jpeg, gif, png, bmp)',
					'value' => 'jpg|jpeg|gif|png|bmp',
				),
				array(
					'label' => 'Audio (mp3, wav, ogg, wma, mka, m4a, ra, mid, midi)',
					'value' => 'mp3|wav|ogg|wma|mka|m4a|ra|mid|midi',
				),
				array(
					'label' => 'Video (avi, divx, flv, mov, ogv, mkv, mp4, m4v, divx, mpg, mpeg, mpe)',
					'value' => 'avi|divx|flv|mov|ogv|mkv|mp4|m4v|divx|mpg|mpeg|mpe',
				),
				array(
					'label' => 'PDF (pdf)',
					'value' => 'pdf',
				),
				array(
					'label' => 'Docs (doc, ppt, pps, xls, mdb, docx, xlsx, pptx, odt, odp, ods, odg, odc, odb, odf, rtf, txt)',
					'value' => 'doc|ppt|pps|xls|mdb|docx|xlsx|pptx|odt|odp|ods|odg|odc|odb|odf|rtf|txt',
				),
				array(
					'label' => 'Zip Archives (zip, gz, gzip, rar, 7z)',
					'value' => 'zip|gz|gzip|rar|7z',
				),
				array(
					'label' => 'Executable Files (exe)',
					'value' => 'exe',
				),
				array(
					'label' => 'CSV (csv)',
					'value' => 'csv',
				),
			),
		),
	'allowed_image_types' =>
		array(
			'template'  => 'inputCheckbox',
			'label'     => 'Allowed Images',
			'help_text' => 'Allowed Images',
			'fileTypes' =>
				array(
					array(
						'title' => 'JPG',
						'types' => array( 'jpg|jpeg', ),
					),
					array(
						'title' => 'PNG',
						'types' => array( 'png' ),
					),
					array(
						'title' => 'GIF',
						'types' => array( 'gif' ),
					),
				),
			'options'   => array(
				array(
					'label' => 'JPG',
					'value' => 'jpg|jpeg',
				),
				array(
					'label' => 'PNG',
					'value' => 'png',
				),
				array(
					'label' => 'GIF',
					'value' => 'gif',
				),
			),
		)
);

return apply_filters( 'fluent_editor_validation_rule_settings', $validation_rule_settings );